# ABC Flow 

The ABC flow (see [hairer2006geometric](@cite)) is described by a divergence-free differential equation whose flow strongly depends on the initial condition. 

```@example
using GeometricIntegrators: integrate, ImplicitMidpoint
using GeometricProblems.ABCFlow
using GeometricEquations: EnsembleProblem
using GeometricSolutions: GeometricSolution
using Plots

ics1 = (q = [0., 0., 0.], )
ics2 = (q = [0.5, 0., 0.], )
ics3 = (q = [0.6, 0., 0.], )

ensemble_problem = EnsembleProblem(odeproblem().equation, tspan, tstep, [ics1, ics2, ics3], default_parameters)
ensemble_solution = integrate(ensemble_problem, ImplicitMidpoint())

function plot_geometric_solution!(p::Plots.Plot, solution::GeometricSolution; kwargs...)
    plot!(p, solution.q[:, 1], solution.q[:, 2], solution.q[:, 3]; kwargs...)
end

p = plot()
for solution in ensemble_solution
    plot_geometric_solution!(p, solution)
end

p
```

## Library functions

```@docs 
GeometricProblems.ABCFlow
```

```@autodocs
Modules = [GeometricProblems.ABCFlow]
Order = [:constant, :type, :macro, :function]
```

```@bibliography
Pages = []

hairer2006geometric
```